@@ -40,6 +40,9 @@ class ServiceLocator(object):
     '''Find service and method from request attributes, check access, 
     invoke with dispatch hooks, handle errors, return result'''
     
+    # Whether ``serviceObj.onException(ex)`` was called
+    exceptionPassed = False 
+    
     serviceObj = self._getService(request.service)
     try:
       methodObj = self._getMethod(serviceObj, request.method)
@@ -60,14 +63,20 @@ class ServiceLocator(object):
       serviceObj.preDispatch(request, methodObj)
       try:
         return methodObj(*args, **kwargs)
+      except Exception as ex:
+        serviceObj.onException(ex)
+        exceptionPassed = True
+        raise
       finally:
         serviceObj.postDispatch(request, methodObj)
     except Error as ex:
-      serviceObj.onException(ex)
+      if not exceptionPassed:
+        serviceObj.onException(ex)
       # Bypass package internal errors
       raise
     except Exception as ex:
-      serviceObj.onException(ex)
+      if not exceptionPassed:
+        serviceObj.onException(ex)
       # Wrap system errors
       if sys.version_info >= (3,):
         raise ApplicationError(ex).with_traceback(sys.exc_info()[2])
@@ -112,7 +121,7 @@ class ServiceLocator(object):
     return moduleObj
   
   def _getService(self, name):
-    '''Get service by full name'''
+    '''Get service by full name. Note that cached are service classes, not service instances.'''
     
     if name not in self.__cache:
       self.__cache[name] = self._loadClass(name)
