@@ -119,6 +119,13 @@ def allow(*forRoles):
 
   return _allow
 
+def brokenAllow(*forRoles):
+  # allows access for any of provided roles
+  def _allow(method, request):
+    raise AttributeError('Some sort of failure')
+
+  return _allow
+
 class Service(rpc.Service):
 
   state = []
@@ -164,6 +171,10 @@ class Service(rpc.Service):
   def subtract(self, x, y):
     return x - y
   
+  @rpc.access(brokenAllow('foo'))
+  def authFail(self):
+    pass
+  
   @rpc.public
   def decimal(self):
     return decimal.Decimal('12.13')
@@ -212,7 +223,7 @@ class Service(rpc.Service):
     part = cherrypy.request.params['random-binary']
     hash = hashlib.md5(part.file.read()).hexdigest()
     
-    # XHR upload IE iframe fallback. Response is accessible only if mime is set to plain/text.
+    # XHR upload IE iframe fallback. Response is accessible only if MIME is set to plain/text.
     cherrypy.response.headers['content-type'] = 'text/plain'
     
     return dict(hash = hash, passthrough = passthrough)
