@@ -273,19 +273,19 @@ class TestGeneral(test.TestCase):
 
     self.assertEqual(3, len(test.Service.state))
     
-    self.assertIs(test.Service.state[0][1], test.Service.state[1][1], 'same Request object')
+    self.assertIs(test.Service.state[0][1], test.Service.state[2][1], 'same Request object')
     
     item = test.Service.state.pop(0)
     self.assertEqual('preDispatch', item[0])
     self.assertIsInstance(item[1], rpc.Request)
-
-    item = test.Service.state.pop(0)
-    self.assertEqual('postDispatch', item[0])
-    self.assertIsInstance(item[1], rpc.Request)
     
     item = test.Service.state.pop(0)
     self.assertEqual('onException', item[0])
     self.assertIsInstance(item[1], ValueError)
+
+    item = test.Service.state.pop(0)
+    self.assertEqual('postDispatch', item[0])
+    self.assertIsInstance(item[1], rpc.Request)
     
     response = json.loads(self.body.decode('ascii'))
     self.assertEqual({
@@ -303,19 +303,19 @@ class TestGeneral(test.TestCase):
 
     self.assertEqual(3, len(test.Service.state))
     
-    self.assertIs(test.Service.state[0][1], test.Service.state[1][1], 'same Request object')
+    self.assertIs(test.Service.state[0][1], test.Service.state[2][1], 'same Request object')
     
     item = test.Service.state.pop(0)
     self.assertEqual('preDispatch', item[0])
     self.assertIsInstance(item[1], rpc.Request)
-
-    item = test.Service.state.pop(0)
-    self.assertEqual('postDispatch', item[0])
-    self.assertIsInstance(item[1], rpc.Request)
     
     item = test.Service.state.pop(0)
     self.assertEqual('onException', item[0])
     self.assertIsInstance(item[1], rpc.ApplicationError)
+
+    item = test.Service.state.pop(0)
+    self.assertEqual('postDispatch', item[0])
+    self.assertIsInstance(item[1], rpc.Request)
     
     response = json.loads(self.body.decode('ascii'))
     self.assertEqual({
@@ -333,19 +333,19 @@ class TestGeneral(test.TestCase):
 
     self.assertEqual(3, len(test.Service.state))
     
-    self.assertIs(test.Service.state[0][1], test.Service.state[1][1], 'same Request object')
+    self.assertIs(test.Service.state[0][1], test.Service.state[2][1], 'same Request object')
     
     item = test.Service.state.pop(0)
     self.assertEqual('preDispatch', item[0])
     self.assertIsInstance(item[1], rpc.Request)
-
-    item = test.Service.state.pop(0)
-    self.assertEqual('postDispatch', item[0])
-    self.assertIsInstance(item[1], rpc.Request)
     
     item = test.Service.state.pop(0)
     self.assertEqual('onException', item[0])
     self.assertIsInstance(item[1], rpc.PermissionDeniedError)
+
+    item = test.Service.state.pop(0)
+    self.assertEqual('postDispatch', item[0])
+    self.assertIsInstance(item[1], rpc.Request)
     
     response = json.loads(self.body.decode('ascii'))
     self.assertEqual({
@@ -700,6 +700,28 @@ class TestAccess(test.TestCase):
     response = json.loads(self.body.decode('ascii'))
     self.assertTrue(response['error'] is None)
     self.assertEqual(13 - 12, response['result'])
+    
+  def testBrokenAccessCheck(self):
+    request = json.dumps({
+      'id'      : 1,
+      'service' : 'qxcpjsonrpc.test.Service',
+      'method'  : 'authFail',
+      'params'  : []
+    })
+    headers = [('content-length', str(len(request)))]
+    
+    self.getPage('/service', method = 'post', body = request, headers = headers)
+    
+    self.assertStatus(200)
+    self.assertHeader('content-type', 'application/json')
+    
+    response = json.loads(self.body.decode('ascii'))
+    self.assertTrue(response['result'] is None)
+    self.assertEqual('[ApplicationError] Some sort of failure', response['error']['message'])
+    
+    item = test.Service.state.pop(0)
+    self.assertEqual('onException', item[0])
+    self.assertIsInstance(item[1], AttributeError)
   
   def testAccessForbidden(self):
     request = json.dumps({
